@@ -5,13 +5,14 @@ use crate::core::intermediary;
 pub struct DefaultImpl;
 
 
-impl implementation::Trait<&intermediary::DataContext> for DefaultImpl {
-    fn gen(data_context_ref: &intermediary::DataContext) -> proc_macro2::TokenStream {
+impl<'a> implementation::Trait<&'a intermediary::DataContext<'a>> for DefaultImpl {
+    fn gen(data_context_ref: &'a intermediary::DataContext<'a>) -> proc_macro2::TokenStream {
         let data_context_ident_ref = &data_context_ref.ident;
+        let data_context_generics_ref = data_context_ref.generics_ref;
         let data_context_field_ident_vec_ref = &data_context_ref.field_ident_vec;
 
         quote!{
-            impl Default for #data_context_ident_ref {
+            impl #data_context_generics_ref Default for #data_context_ident_ref #data_context_generics_ref {
                 fn default() -> Self {
                     #data_context_ident_ref {
                         #(#data_context_field_ident_vec_ref: None,
