@@ -12,14 +12,15 @@ use crate::core::intermediary;
 pub struct DataContext;
 
 
-impl implementation::Trait<&intermediary::DataContext> for DataContext {
-    fn gen(data_context_ref: &intermediary::DataContext) -> proc_macro2::TokenStream {
+impl<'a> implementation::Trait<&'a intermediary::DataContext<'a>> for DataContext {
+    fn gen(data_context_ref: &'a intermediary::DataContext<'a>) -> proc_macro2::TokenStream {
         let data_context_ident_ref = &data_context_ref.ident;
+        let data_context_generics_ref = data_context_ref.generics_ref;
         let data_context_field_ident_vec_ref = &data_context_ref.field_ident_vec;
         let data_context_field_type_vec_ref = &data_context_ref.field_type_vec;
 
         quote!{
-            pub struct #data_context_ident_ref {
+            pub struct #data_context_ident_ref #data_context_generics_ref {
                 #(#data_context_field_ident_vec_ref: #data_context_field_type_vec_ref,
                 )*
             }
