@@ -14,7 +14,7 @@ pub struct DeserializerTraitImpl;
 pub struct ParameterStruct<'a> {
     pub struct_definition_ref: &'a definition::Struct,
     pub struct_intermediary_ref: &'a intermediary::Struct<'a>,
-    pub struct_data_context_intermediary_ref: &'a intermediary::DataContext,
+    pub struct_data_context_intermediary_ref: &'a intermediary::DataContext<'a>,
     pub struct_deserializer_intermediary_ref: &'a intermediary::deserializer::Struct,
 }
 
@@ -22,81 +22,99 @@ pub struct ParameterStruct<'a> {
 pub struct ParameterEnum<'a> {
     pub enum_definition_ref: &'a definition::Enum,
     pub enum_intermediary_ref: &'a intermediary::Enum<'a>,
-    pub enum_variable_complex_data_context_intermediary_vec_ref: &'a Vec<intermediary::DataContext>,
+    pub enum_variable_complex_data_context_intermediary_vec_ref: &'a Vec<intermediary::DataContext<'a>>,
     pub enum_deserializer_intermediary_ref: &'a intermediary::deserializer::Enum,
 }
 
 
 impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
     fn gen(parameter: ParameterStruct) -> proc_macro2::TokenStream {
-        let generics = if parameter.struct_definition_ref.data_struct.fields.is_empty() {
-            let mut generic_vec = Vec::new();
-            for type_ref in parameter.struct_intermediary_ref.field_type_vec.iter() {
-                generic_vec.push(quote!{ #type_ref: flexpiler::Deserialization<flexpiler::common::rustc::Format> });
-            }
-            quote!{
-                where #(#generic_vec)*
-            }
-        } else {
-            quote!{}
-        };
+        let generics_where = implementation::GenericsWhere::gen(implementation::generics_where::ParameterStruct{
+            definition_struct_ref: parameter.struct_definition_ref,
+            intermediary_struct_ref: parameter.struct_intermediary_ref,
+        });
 
         let struct_definition_ident_ref = &parameter.struct_definition_ref.ident;
+        let struct_definition_generics_ref = &parameter.struct_definition_ref.generics;
         let struct_intermediary_ident_string_ref = &parameter.struct_intermediary_ref.ident_string;
         let struct_intermediary_field_string_vec_ref = &parameter.struct_intermediary_ref.field_string_vec;
         let struct_intermediary_field_type_vec_ref = &parameter.struct_intermediary_ref.field_type_vec;
         let struct_deserializer_intermediary_ident_ref = &parameter.struct_deserializer_intermediary_ref.ident;
         let struct_data_context_intermediary_ident_ref = &parameter.struct_data_context_intermediary_ref.ident;
+        let struct_data_context_intermediary_generics_ref = parameter.struct_data_context_intermediary_ref.generics_ref;
         let struct_data_context_intermediary_field_ident_vec_ref = &parameter.struct_data_context_intermediary_ref.field_ident_vec;
 
         quote!{
-            impl flexpiler::deserializer::Trait<#struct_definition_ident_ref, flexpiler::common::rustc::deserializer::Context> for #struct_deserializer_intermediary_ident_ref
-            #generics {
+            impl #struct_definition_generics_ref flexpiler::deserializer::Trait<
+                #struct_definition_ident_ref #struct_definition_generics_ref,
+                flexpiler::common::rustc::Format,
+            > for #struct_deserializer_intermediary_ident_ref
+            #generics_where {
                 fn deserialize<ReaderType>(reader_mut_ref: &mut ReaderType)
-                    -> std::result::Result<
-                        flexpiler::deserializer::Result<#struct_definition_ident_ref, flexpiler::common::rustc::deserializer::Context>,
-                        flexpiler::Error>
+                    -> flexpiler::deserializer::Result<
+                        #struct_definition_ident_ref #struct_definition_generics_ref,
+                        flexpiler::common::rustc::deserializer::Context,
+                        flexpiler::Error<flexpiler::common::rustc::error::Source>
+                    >
                 where ReaderType: flexpiler::reader::Trait {
-
-                    use std::convert::TryInto;
-                    use flexpiler::Deserialization;
                     use flexpiler::deserializer::Trait as DeserializerTrait;
+                    use flexpiler::deserializer::context::Trait as DeserializerContextTrait;
                     use flexpiler::error::Trait as ErrorTrait;
+                    use flexpiler::error::propagation::Trait as ErrorPropagationTrait;
+                    use flexpiler::identity::Trait;
                     use flexpiler::parser::Parse;
 
-                    let struct_declaration_string = match flexpiler::common::rustc::block::IdentifierWithDataStartFinish::parse(reader_mut_ref) {
+                    let (identifier_data, identifier_finish) = match flexpiler::common::rustc::block::Identifier::parse(reader_mut_ref) {
+                        Ok(flexpiler::common::rustc::block::identifier::Result::NoDataFound { finish }) => {
+                            return flexpiler::deserializer::Result::NoDataFound {
+                                context: finish.into()
+                            };
+                        },
+                        Ok(flexpiler::common::rustc::block::identifier::Result::DataFound { data, finish }) => {
+                            (data, finish)
+                        },
                         Err(parser_error) => {
                             let error = flexpiler::Error::gen(parser_error)
-                                .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                            return Err(error);
-                        },
-                        Ok(flexpiler::common::rustc::block::identifier_with_data_start_finish::Result::DataStartFinish(declaration)) => {
-                            declaration
-                        },
-                        Ok(flexpiler::common::rustc::block::identifier_with_data_start_finish::Result::Freestanding(declaration)) => {
-                            match flexpiler::common::rustc::block::DataStart::parse(reader_mut_ref) {
-                                Err(parser_error) => {
-                                    let error = flexpiler::Error::gen(parser_error)
-                                        .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                                    return Err(error);
-                                },
-                                Ok(_) => {
-                                    // successfully parsed data start
-                                },
-                            }
-
-                            declaration
-                        },
+                                .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                            return flexpiler::deserializer::Result::Err(error);
+                        }
                     };
+                    let mut context: flexpiler::common::rustc::deserializer::Context = identifier_finish.into();
+                    if context == flexpiler::common::rustc::deserializer::Context::Freestanding {
+                        context = match flexpiler::common::rustc::block::ContextDenominator::parse(reader_mut_ref) {
+                            Ok(result) => {
+                                result.finish.into()
+                            },
+                            Err(parser_error) => {
+                                let error = flexpiler::Error::gen(parser_error)
+                                    .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                                return flexpiler::deserializer::Result::Err(error);
+                            },
+                        }
+                    }
+                    match context {
+                        flexpiler::common::rustc::deserializer::Context::DataStart => {},
+                        _ => {
+                            let unexpected_context = flexpiler::common::rustc::error::UnexpectedContext {
+                                context_found: context,
+                                context_expected: flexpiler::error::ExpectedEntries::from(vec![
+                                    flexpiler::common::rustc::deserializer::Context::DataStart,
+                                ]),
+                            };
+                            let error = flexpiler::Error::gen(unexpected_context)
+                                .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                            return flexpiler::deserializer::Result::Err(error);
+                        },
+                    }
 
-                    if struct_declaration_string.as_str() != #struct_intermediary_ident_string_ref {
-                        let incompatible_struct_declaration = flexpiler::error::IncompatibleStructDeclaration {
+                    if identifier_data.as_str() != #struct_intermediary_ident_string_ref {
+                        let incompatible_struct_declaration = flexpiler::common::rustc::error::IncompatibleStructDeclaration {
                             struct_declaration_expected: String::from(#struct_intermediary_ident_string_ref),
-                            struct_declaration_found: struct_declaration_string,
+                            struct_declaration_found: identifier_data,
                         };
                         let error = flexpiler::Error::gen(incompatible_struct_declaration)
-                            .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                        return Err(error);
+                            .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                        return flexpiler::deserializer::Result::Err(error);
                     }
 
                     let mut struct_context = #struct_data_context_intermediary_ident_ref::default();
@@ -105,8 +123,8 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                         let field_declaration_string = match flexpiler::common::rustc::block::DeclarationOrDataEnd::parse(reader_mut_ref) {
                             Err(parser_error) => {
                                 let error = flexpiler::error::Error::gen(parser_error)
-                                    .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                                return Err(error);
+                                    .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                                return flexpiler::deserializer::Result::Err(error);
                             },
                             Ok(flexpiler::common::rustc::block::declaration_or_data_end::Result::DataEnd()) => {
                                 break;
@@ -116,18 +134,27 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                             },
                         };
 
-                        let context = match field_declaration_string.as_str() {
+                        let mut context = match field_declaration_string.as_str() {
                             #(#struct_intermediary_field_string_vec_ref => {
                                 let result = <#struct_intermediary_field_type_vec_ref as flexpiler::Deserialization<flexpiler::common::rustc::Format>>
                                             ::Deserializer::deserialize(reader_mut_ref);
                                 match result {
-                                    Ok(value) => {
-                                        struct_context.#struct_data_context_intermediary_field_ident_vec_ref = Some(value.data);
-                                        value.context
-                                    }
-                                    Err(error) => {
-                                        let error = error.propagate(#struct_deserializer_intermediary_ident_ref::context_field(#struct_intermediary_field_string_vec_ref));
-                                        return Err(error);
+                                    flexpiler::deserializer::Result::DataFound{ data, context } => {
+                                        struct_context.#struct_data_context_intermediary_field_ident_vec_ref = Some(data);
+                                        context
+                                    },
+                                    flexpiler::deserializer::Result::NoDataFound { context } => {
+                                        let unexpected_no_content = flexpiler::error::source::common::UnexpectedNoContent {
+                                            definition_expected: <#struct_intermediary_field_type_vec_ref as flexpiler::identity::Trait>::definition(),
+                                        };
+                                        let error_source_common: flexpiler::error::source::Common = unexpected_no_content.into();
+                                        let error = flexpiler::Error::gen(error_source_common)
+                                            .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::FieldTrait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context_field(#struct_intermediary_field_string_vec_ref));
+                                        return flexpiler::deserializer::Result::Err(error);
+                                    },
+                                    flexpiler::deserializer::Result::Err(error) => {
+                                        let error = error.propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::FieldTrait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context_field(#struct_intermediary_field_string_vec_ref));
+                                        return flexpiler::deserializer::Result::Err(error);
                                     }
                                 }
                             }
@@ -135,7 +162,7 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                             )*
 
                             _ => {
-                                let unrecognized_field = flexpiler::error::UnrecognizedFieldDeclaration {
+                                let unrecognized_field = flexpiler::common::rustc::error::UnrecognizedFieldDeclaration {
                                     field_declaration_found: field_declaration_string,
                                     field_declaration_expected_entries: flexpiler::error::ExpectedEntries::from(vec![
                                         #(String::from(#struct_intermediary_field_string_vec_ref),
@@ -143,27 +170,25 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                                     ]),
                                 };
                                 let error = flexpiler::Error::gen(unrecognized_field)
-                                    .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                                return Err(error);
+                                    .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                                return flexpiler::deserializer::Result::Err(error);
                             }
                         };
 
-                        match context {
-                            flexpiler::common::rustc::deserializer::Context::Freestanding => {
-                                match flexpiler::common::rustc::block::DataEndOrSeparator::parse(reader_mut_ref) {
-                                    Ok(flexpiler::common::rustc::block::data_end_or_separator::Result::DataEnd) => {
-                                        break;
-                                    },
-                                    Ok(flexpiler::common::rustc::block::data_end_or_separator::Result::Separator) => {
-                                        // do nothing
-                                    },
-                                    Err(parser_error) => {
-                                        let error = flexpiler::error::Error::gen(parser_error)
-                                            .propagate(#struct_deserializer_intermediary_ident_ref::context_field(field_declaration_string.as_str()));
-                                        return Err(error);
-                                    },
+                        if context == flexpiler::common::rustc::deserializer::Context::Freestanding {
+                            match flexpiler::common::rustc::block::ContextDenominator::parse(reader_mut_ref) {
+                                Ok(result) => {
+                                    context = result.finish.into();
+                                },
+                                Err(parser_error) => {
+                                    let error = flexpiler::Error::gen(parser_error)
+                                        .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                                    return flexpiler::deserializer::Result::Err(error);
                                 }
-                            },
+                            }
+                        }
+
+                        match context {
                             flexpiler::common::rustc::deserializer::Context::DataEnd => {
                                 break;
                             },
@@ -171,7 +196,7 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                                 // do nothing
                             },
                             _ => {
-                                let unexpected_entry_finish_context = flexpiler::error::UnexpectedEntryFinishContext {
+                                let unexpected_entry_finish_context = flexpiler::common::rustc::error::UnexpectedEntryFinishContext {
                                     entry_declaration: field_declaration_string,
                                     context_expected: flexpiler::error::ExpectedEntries::from(vec![
                                         flexpiler::common::rustc::deserializer::Context::DataEnd,
@@ -180,21 +205,21 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
                                     context_found: context,
                                 };
                                 let error = flexpiler::Error::gen(unexpected_entry_finish_context)
-                                    .propagate(#struct_deserializer_intermediary_ident_ref::context_general());
-                                return Err(error);
+                                    .propagate(<#struct_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#struct_definition_ident_ref #struct_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                                return flexpiler::deserializer::Result::Err(error);
                             }
                         }
                     } // loop
 
-                    return match struct_context.try_into() {
+                    return match <#struct_data_context_intermediary_ident_ref #struct_data_context_intermediary_generics_ref as std::convert::TryInto<#struct_definition_ident_ref #struct_definition_generics_ref>>::try_into(struct_context) {
                         Ok(data) => {
-                            Ok(flexpiler::deserializer::Result {
+                            flexpiler::deserializer::Result::DataFound {
                                 context: flexpiler::common::rustc::deserializer::Context::Freestanding,
                                 data,
-                            })
+                            }
                         },
                         Err(error) => {
-                            Err(error)
+                            flexpiler::deserializer::Result::Err(error)
                         },
                     }
                 }
@@ -206,28 +231,13 @@ impl<'a> implementation::Trait<ParameterStruct<'a>> for DeserializerTraitImpl {
 
 impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
     fn gen(parameter: ParameterEnum) -> proc_macro2::TokenStream {
-        let generics = {
-            let mut generic_vec = Vec::new();
-            for variable_argumented_ref in parameter.enum_intermediary_ref.variant_argumented_vec.iter() {
-                for type_ref in variable_argumented_ref.field_type_ref_vec.iter() {
-                    generic_vec.push(quote!{ #type_ref: flexpiler::Deserialization<flexpiler::common::rustc::Format>, });
-                }
-            }
-            for variable_complex_ref in parameter.enum_intermediary_ref.variant_complex_vec.iter() {
-                for type_ref in variable_complex_ref.field_type_ref_vec.iter() {
-                    generic_vec.push(quote!{ #type_ref: flexpiler::Deserialization<flexpiler::common::rustc::Format>, });
-                }
-            }
-            if generic_vec.is_empty() {
-                quote!{}
-            } else {
-                quote!{
-                    where #(#generic_vec)*
-                }
-            }
-        };
+        let generics_where = implementation::GenericsWhere::gen(implementation::generics_where::ParameterEnum{
+            definition_enum_ref: parameter.enum_definition_ref,
+            intermediary_enum_ref: parameter.enum_intermediary_ref,
+        });
 
         let enum_definition_ident_ref = &parameter.enum_definition_ref.ident;
+        let enum_definition_generics_ref = &parameter.enum_definition_ref.generics;
         let enum_intermediary_ident_string_ref = &parameter.enum_intermediary_ref.ident_string;
         let enum_deserializer_intermediary_ident_ref = &parameter.enum_deserializer_intermediary_ref.ident;
         let enum_variant_ident_string_ref_vec = {
@@ -254,11 +264,11 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
 
                 vec.push(quote!{
                     #variant_standalone_full_ident_string_ref => {
-                        let context: flexpiler::common::rustc::deserializer::Context = declaration_result.finish.into();
-                        Ok(flexpiler::deserializer::Result {
+                        let context: flexpiler::common::rustc::deserializer::Context = identifier_finish.into();
+                        flexpiler::deserializer::Result::DataFound {
                             data: #variant_standalone_full_ident_ref,
                             context
-                        })
+                        }
                     }
                 });
             }
@@ -268,16 +278,18 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
         let enum_variant_argumented_deserialization_code_vec = {
             let mut vec = Vec::new();
             for variant_argumented_ref in parameter.enum_intermediary_ref.variant_argumented_vec.iter() {
+                let variant_argumented_ident_string_ref = &variant_argumented_ref.ident_string;
                 let variant_argumented_full_ident_string_ref = &variant_argumented_ref.full_ident_string;
 
                 let deserialization_code = DataArgumentedDeserialization::gen(data_argumented_deserialization::ParameterEnumVariableArgumented{
+                    enum_definition_ref: parameter.enum_definition_ref,
                     enum_deserializer_intermediary_ref: &parameter.enum_deserializer_intermediary_ref,
                     variant_argumented_intermediary_ref: variant_argumented_ref,
                 });
 
                 vec.push(quote!{
                     #variant_argumented_full_ident_string_ref => {
-                        let context: flexpiler::common::rustc::deserializer::Context = declaration_result.finish.into();
+                        let context: flexpiler::common::rustc::deserializer::Context = identifier_finish.into();
                         match context {
                             flexpiler::common::rustc::deserializer::Context::Freestanding => {
                                 match flexpiler::parser::parse::<
@@ -286,23 +298,23 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
                                 >(reader_mut_ref) {
                                     Ok(result) => {},
                                     Err(parser_error) => {
-                                        let error = flexpiler::error::Error::gen(parser_error)
-                                            .propagate(#enum_deserializer_intermediary_ident_ref::context_entry_general(#variant_argumented_full_ident_string_ref));
-                                        return Err(error);
+                                        let error = flexpiler::Error::gen(parser_error)
+                                            .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::VariantTrait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context_variant(#variant_argumented_ident_string_ref));
+                                        return flexpiler::deserializer::Result::Err(error);
                                     },
                                 }
                             },
                             flexpiler::common::rustc::deserializer::Context::ArgumentStart => {
                             },
                             _ => {
-                                let incompatible_enum_data_type = flexpiler::error::IncompatibleEnumDataType {
-                                    enum_declaration_found: declaration_result.identifier_string,
-                                    enum_data_type_expected: flexpiler::error::incompatibleenumdataType::EnumDataType::Argument,
+                                let incompatible_enum_data_type = flexpiler::common::rustc::error::IncompatibleEnumDataType {
+                                    enum_declaration_found: identifier_data,
+                                    enum_data_type_expected: flexpiler::common::rustc::error::incompatibleenumdataType::EnumDataType::Argument,
                                     context_found: context,
                                 };
                                 let error = flexpiler::Error::gen(incompatible_enum_data_type)
-                                    .propagate(#enum_deserializer_intermediary_ident_ref::context_entry_general(#variant_argumented_full_ident_string_ref));
-                                return Err(error);
+                                    .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::VariantTrait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context_variant(#variant_argumented_ident_string_ref));
+                                return flexpiler::deserializer::Result::Err(error);
                             }
                         }
 
@@ -320,6 +332,7 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
                 let variant_complex_full_ident_string_ref = &variant_complex_ref.full_ident_string;
 
                 let deserialization_code = DataContextDeserialization::gen(data_context_deserialization::ParameterEnumVariableComplex{
+                    enum_definition_ref: parameter.enum_definition_ref,
                     enum_deserializer_intermediary_ref: &parameter.enum_deserializer_intermediary_ref,
                     variable_complex_intermediary_ref: variant_complex_ref,
                     data_context_intermediary_ref: variant_complex_data_context_intermediary_ref
@@ -327,7 +340,7 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
 
                 vec.push(quote!{
                     #variant_complex_full_ident_string_ref => {
-                        let context: flexpiler::common::rustc::deserializer::Context = declaration_result.finish.into();
+                        let context: flexpiler::common::rustc::deserializer::Context = identifier_finish.into();
                         match context {
                             flexpiler::common::rustc::deserializer::Context::Freestanding => {
                                 match flexpiler::parser::parse::<
@@ -337,22 +350,22 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
                                     Ok(result) => {},
                                     Err(parser_error) => {
                                         let error = flexpiler::error::Error::gen(parser_error)
-                                            .propagate(#enum_deserializer_intermediary_ident_ref::context_entry_general(#variant_complex_full_ident_string_ref));
-                                        return Err(error);
+                                            .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::VariantTrait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context_variant(#variant_complex_full_ident_string_ref));
+                                        return flexpiler::deserializer::Result::Err(error);
                                     },
                                 }
                             },
                             flexpiler::common::rustc::deserializer::Context::DataStart => {
                             },
                             _ => {
-                                let incompatible_enum_data_type = flexpiler::error::IncompatibleEnumDataType {
-                                    enum_declaration_found: declaration_result.identifier_string,
-                                    enum_data_type_expected: flexpiler::error::incompatibleenumdataType::EnumDataType::Complex,
+                                let incompatible_enum_data_type = flexpiler::common::rustc::error::IncompatibleEnumDataType {
+                                    enum_declaration_found: identifier_data,
+                                    enum_data_type_expected: flexpiler::common::rustc::error::incompatibleenumdataType::EnumDataType::Complex,
                                     context_found: context,
                                 };
                                 let error = flexpiler::Error::gen(incompatible_enum_data_type)
-                                    .propagate(#enum_deserializer_intermediary_ident_ref::context_entry_general(#variant_complex_full_ident_string_ref));
-                                return Err(error);
+                                    .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::VariantTrait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context_variant(#variant_complex_full_ident_string_ref));
+                                return flexpiler::deserializer::Result::Err(error);
                             }
                         }
 
@@ -364,29 +377,36 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
         };
 
         quote!{
-            impl flexpiler::deserializer::Trait<#enum_definition_ident_ref, flexpiler::common::rustc::deserializer::Context> for #enum_deserializer_intermediary_ident_ref
-            #generics {
+            impl #enum_definition_generics_ref flexpiler::deserializer::Trait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format> for #enum_deserializer_intermediary_ident_ref
+            #generics_where {
                 fn deserialize<ReaderType>(reader_mut_ref: &mut ReaderType)
-                    -> std::result::Result<
-                        flexpiler::deserializer::Result<#enum_definition_ident_ref, flexpiler::common::rustc::deserializer::Context>,
-                        flexpiler::Error>
+                    -> flexpiler::deserializer::Result<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::deserializer::Context, flexpiler::Error<flexpiler::common::rustc::error::Source>>
                 where ReaderType: flexpiler::reader::Trait {
                     use std::convert::TryInto;
                     use flexpiler::Deserialization;
                     use flexpiler::deserializer::Trait as DeserializerTrait;
+                    use flexpiler::deserializer::context::VariantTrait as DeserializerContextVariantTrait;
                     use flexpiler::error::Trait as ErrorTrait;
+                    use flexpiler::error::propagation::Trait as ErrorPropagationTrait;
                     use flexpiler::parser::Parse;
 
-                    let declaration_result = match flexpiler::common::rustc::block::IdentifierWithVariableFinish::parse(reader_mut_ref) {
+                    let (identifier_data, identifier_finish) = match flexpiler::common::rustc::block::Identifier::parse(reader_mut_ref) {
                         Err(parser_error) => {
-                            let error = flexpiler::Error::gen(parser_error)
-                                .propagate(#enum_deserializer_intermediary_ident_ref::context_general());
-                            return Err(error);
+                            let error = flexpiler::error::Error::gen(parser_error)
+                                .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                            return flexpiler::deserializer::Result::Err(error);
+                        },
+                        Ok(flexpiler::common::rustc::block::identifier::Result::NoDataFound { finish }) => {
+                            return flexpiler::deserializer::Result::NoDataFound {
+                                context: finish.into()
+                            };
+                        },
+                        Ok(flexpiler::common::rustc::block::identifier::Result::DataFound { data, finish }) => {
+                            (data, finish)
                         },
-                        Ok(result) => result,
                     };
 
-                    let result = match declaration_result.identifier_string.as_str() {
+                    let result = match identifier_data.as_str() {
                         #(#enum_variant_standalone_deserialization_code_vec
                         )*
                         #(#enum_variant_argumented_deserialization_code_vec
@@ -395,15 +415,15 @@ impl<'a> implementation::Trait<ParameterEnum<'a>> for DeserializerTraitImpl {
                         )*
 
                         _ => {
-                            let incompatible_enum_declaration = flexpiler::error::IncompatibleEnumDeclaration {
-                                enum_declaration_found: declaration_result.identifier_string,
+                            let incompatible_enum_declaration = flexpiler::common::rustc::error::IncompatibleEnumDeclaration {
+                                enum_declaration_found: identifier_data,
                                 enum_declaration_expected_entries: flexpiler::error::ExpectedEntries::from(vec![
                                     #(std::string::String::from(#enum_variant_ident_string_ref_vec),)*
                                 ]),
                             };
                             let error = flexpiler::Error::gen(incompatible_enum_declaration)
-                                .propagate(#enum_deserializer_intermediary_ident_ref::context_general());
-                            return Err(error);
+                                .propagate(<#enum_deserializer_intermediary_ident_ref as flexpiler::deserializer::context::Trait<#enum_definition_ident_ref #enum_definition_generics_ref, flexpiler::common::rustc::Format>>::context());
+                            return flexpiler::deserializer::Result::Err(error);
                         }
                     };
 
